# docs
## start
### install
`import zwack`
### init zwack
`zwack = zwack.Zwack()`

## commands
### ascii
`ascii = zwack.ascii()` (sets ascii to the ascii class)
#### zwack
`ascii.zwack` (returns ascii art of zwack)
#### zwack overflow
##### full icon
`ascii.overflow` (returns full zwack overflow icon ascii art)
##### icon only
`ascii.overflow_small` (returns ascii art of the overflow part of the logo)